@@ -1,6 +1,8 @@
-#' Fivethirtyeight theme for highcharts
+#' Economist theme for highcharts
 #' 
-#' Fivethirtyeight theme for highcharts
+#' Economist theme for highcharts
+#' 
+#' @param ... Named argument to modify the theme
 #' 
 #' @examples 
 #' 
@@ -8,7 +10,7 @@
 #'   hc_add_theme(hc_theme_economist())
 #' 
 #' @export
-hc_theme_economist <- function(){
+hc_theme_economist <- function(...){
   
   theme <-
   list(
@@ -63,9 +65,6 @@ hc_theme_economist <- function(){
       itemStyle = list(
         color = '#3C3C3C'
       ),
-      itemHoverStyle = list(
-        color = '#FFF'
-      ),
       itemHiddenStyle = list(
         color = '#606063'
       )
@@ -108,6 +107,13 @@ hc_theme_economist <- function(){
   
   theme <- structure(theme, class = "hc_theme")
   
+  if (length(list(...)) > 0) {
+    theme <- hc_theme_merge(
+      theme,
+      hc_theme(...)
+    )
+  } 
+  
   theme
   
 }
