@@ -2,13 +2,15 @@
 #' 
 #' Google theme for highcharts based on https://books.google.com/ngrams/
 #' 
+#' @param ... Named argument to modify the theme
+#' 
 #' @examples 
 #' 
 #' hc_demo() %>% 
 #'   hc_add_theme(hc_theme_google())
 #' 
 #' @export
-hc_theme_google <- function(){
+hc_theme_google <- function(...){
   
   theme <-
   list(
@@ -45,6 +47,13 @@ hc_theme_google <- function(){
   
   theme <- structure(theme, class = "hc_theme")
   
+  if (length(list(...)) > 0) {
+    theme <- hc_theme_merge(
+      theme,
+      hc_theme(...)
+    )
+  } 
+  
   theme
   
 }
