@@ -2,13 +2,15 @@
 #' 
 #' Null theme for highcharts. Axis are removed (\code{visible = FALSE}).
 #' 
+#' @param ... Named argument to modify the theme
+#' 
 #' @examples
 #' 
 #' hc_demo() %>% 
 #'   hc_add_theme(hc_theme_null())
 #'   
 #' @export
-hc_theme_null <- function(){
+hc_theme_null <- function(...){
   
   theme <-   
   list(
@@ -38,6 +40,13 @@ hc_theme_null <- function(){
   
   theme <- structure(theme, class = "hc_theme")
   
+  if (length(list(...)) > 0) {
+    theme <- hc_theme_merge(
+      theme,
+      hc_theme(...)
+    )
+  } 
+  
   theme
   
 }
